staff <- read.csv("StAndrewsORCID_dept_pre-postSurvey.csv")
ORCIDcounts <- read.csv("StAndrewsORCID_pre-postSurvey.csv")
staff[is.na(staff)] <- 0
#

#----dataCleaning 
library(ggplot2) # load ggplot
library(scales)
library(gridExtra)

########FUNCTIONS
label_wrap_mod <- function(value, width = 25){
  sapply(strwrap(as.character(value), width=width, simplify=FALSE),paste, collapse="\n")
}


##----ORCIDcount_dept
# all staff and students
staff_subset <-subset(staff, aggStaff$Unit !="Total")
staff_subset$increase <- staff_subset$ORCID_post_count_ALL - staff_subset$ORCID_pre_count_ALL 
staff_melt <-melt(staff_subset, id.vars =c("Unit", "percentAll_post"), measure.vars=c("increase","ORCID_pre_count_ALL"))

DeptIDs <- ggplot(data=staff_melt, aes(x=reorder(label_wrap_mod(Unit, width=40), value,sum), value, fill=variable))+
  geom_bar(stat="Identity", width=0.8)+ coord_flip() +
  scale_fill_manual(values = c("YellowGreen","Gray75"), labels=c("new ORCID iDs","pre-survey")) +
  theme(axis.text.y=element_blank(),axis.title.y = element_blank(), text = element_text(size=12), legend.position = "top", legend.title =element_blank(),panel.background = element_rect(fill="white")) +
  geom_text(data=subset(staff_melt, value> 0),aes(label=value), color="white",position=position_stack(vjust=0.5),size=3)+  
  geom_text(data=subset(staff_subset, percentAll_post > 0 & percentAll_post !="Inf"), aes(y=28,x=reorder(label_wrap_mod(Unit, width=40),ORCID_post_count_ALL,sum), label=paste(sprintf("(%0.1f",percentAll_post),"%)"), fill=NULL), color="gray30",size=3)+
  geom_text(data=staff_subset,aes(y=24, x=reorder(label_wrap_mod(Unit, width=40), ORCID_post_count_ALL,sum), label=ORCID_post_count_ALL, fill=NULL), size=4, color="gray30")+
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,35))+
  ylab("count")

career_melt <-melt(staff_subset, id.vars = "Unit", measure.vars=grep("ORCID_post_count_s", names(staff_subset), value=TRUE))

DeptStudStaff <- ggplot(career_melt, aes( x=reorder(label_wrap_mod(Unit, width=25), value,sum), y=value, fill=variable))+
  geom_bar(stat="Identity", width=0.8) + coord_flip() +
  scale_fill_manual(values = c("bisque3","bisque4"), labels=c("Staff","Students")) +
  theme(axis.title.y=element_blank(),text = element_text(size=12), legend.title = element_blank(), legend.position="top", panel.background=element_rect(fill="white")) + 
  geom_text(data=subset(career_melt, value >0), aes(x=reorder(label_wrap_mod(Unit, width=25), value,sum), y=value/2, label=value, fill=NULL),vjust=0.3, colour="white", size=3) + 
  ylab("count")

grid.arrange(DeptStudStaff,DeptIDs, ncol=2)

##----ORCIDcount_roles
aggroleORCID <- aggregate(ORCIDcounts[,c("hastoken_pre", "count_pre", "hastoken_post", "count_post")], by=list(ORCIDcounts$Job.Family), FUN=sum, na.rm=TRUE)
aggstaffORCID <- aggregate(staffORCID[c("hastoken_pre", "count_pre", "hastoken_post", "count_post")], by=list(staffORCID$Unit), FUN=sum, na.rm=TRUE)
aggstudORCID <- aggregate(studORCID[c("hastoken_pre", "count_pre", "hastoken_post", "count_post")], by=list(studORCID$Unit), FUN=sum, na.rm=TRUE)
aggAllORCID <- aggregate(ORCIDcounts[c("hastoken_pre", "count_pre", "hastoken_post", "count_post")], by=list(ORCIDcounts$Unit), FUN=sum, na.rm=TRUE)

names(aggroleORCID)[names(aggroleORCID)=="Group.1"] <- "Role"
names(aggstaffORCID)[names(aggstaffORCID) =="Group.1"] <- "Unit"
names(aggstudORCID)[names(aggstudORCID) =="Group.1"] <- "Unit"
names(aggAllORCID)[names(aggAllORCID) =="Group.1"] <- "Unit"

t_staff <- as.data.frame(t(staff[20,c(2:5,7:9)]))
names(t_staff)<- "total"
t_staff$Role <- row.names(t_staff)
aggRole <- merge(aggroleORCID, t_staff,all=TRUE)
aggRole[is.na(aggRole)] <- 0
aggRole$increase <- aggRole$count_post - aggRole$count_pre

# calculate percentages
aggRole$percent_pre <- 100*(aggRole$count_pre/ aggRole$total)
aggRole$percent_post <- 100*(aggRole$count_post/ aggRole$total)
aggRole_melt <- melt(aggRole, id.vars=c("Role", "percent_post"), measure.vars=c("increase", "count_pre"))

ggplot(data=aggRole_melt, aes(x=reorder(label_wrap_mod(Role, width=40), value,sum), value, fill=variable))+
  geom_bar(stat="Identity", width=0.8)+ coord_flip() +
  scale_fill_manual(values = c("YellowGreen","Gray75"), labels=c("new ORCID iDs","pre-survey")) +
  theme(axis.title.y = element_blank(), text = element_text(size=12), legend.position = "top", legend.title =element_blank(),panel.background = element_rect(fill="white")) +
  geom_text(data=aggRole, aes(y=count_post, x=reorder(label_wrap_mod(Role, width=40), count_post,sum), label=count_post, fill=NULL), hjust=-0.5,size=4, color="gray30")+ 
  geom_text(data=subset(aggRole, percent_post >0), aes(y=count_post,x=reorder(label_wrap_mod(Role, width=40),count_post,sum), label=paste(sprintf("(%0.1f",percent_post),"%)"), fill=NULL), color="gray30",hjust=-0.7,size=3)+
  geom_text(data=subset(aggRole, percent_post > 0), aes(y=count_pre/2,x=reorder(label_wrap_mod(Role, width=40),count_pre,sum), label=count_pre, fill=NULL), color="white",size=3)+
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,60))+
  ylab("Count")
