#----base
#setwd("D:/UStA-MSc/Thesis/ORCID-survey/data/surveyAnalysis")
library(ggplot2)
library(scales)
library(reshape)
library(gridExtra)
library(grid)

data <- read.csv("StAndrewsORCIDsurvey_data.csv", stringsAsFactors=FALSE)

#FUNCTIONS
# wrap labels
label_wrap_mod <- function(value, width = 30) {
  sapply(strwrap(as.character(value), width=width, simplify=FALSE), paste, collapse="\n")}

# functions to generate stacked summary datasets for multiple choice questions
multiSelection <- function(dataset, question)
{
  prefix <- question
  dataset <- dataset
  prefix_stack <- melt(dataset, id.vars="ResponseId", measure.vars = grep(toString(prefix), names(dataset), value = TRUE))
  prefix_stack[prefix_stack == ""] <- NA # exclude cases without answer
  prefix_stack <- prefix_stack[complete.cases(prefix_stack),]
  prefix_stack
}
multiSelection2 <- function(data, question)
{
  prefix <- question
  data <- data
  prefix_stack <- melt(data, id.vars="ResponseId", measure.vars = grep(toString(prefix), names(data), value = TRUE))
  prefix_stack[prefix_stack == ""] <- 0 # setting NA to zero because of problem with the slider question
  prefix_stack <- prefix_stack[complete.cases(prefix_stack),]
  prefix_stack
}

# Arrange graphs together with a single shared legend 
grid_arrange_shared_legend <- function(..., ncol = length(list(...)), nrow = 1, position = c("bottom", "right")) {
  plots <- list(...)
  position <- match.arg(position)
  g <- ggplotGrob(plots[[1]] + theme(legend.position = position))$grobs
  legend <- g[[which(sapply(g, function(x) x$name) == "guide-box")]]
  lheight <- sum(legend$height)
  lwidth <- sum(legend$width)
  gl <- lapply(plots, function(x) x + theme(legend.position="none"))
  gl <- c(gl, ncol = ncol, nrow = nrow)
  
  combined <- switch(position,
                     "bottom" = arrangeGrob(do.call(arrangeGrob, gl),
                                            legend,
                                            ncol = 1,
                                            heights = unit.c(unit(1, "npc") - lheight, lheight)),
                     "right" = arrangeGrob(do.call(arrangeGrob, gl),
                                           legend,
                                           ncol = 2,
                                           widths = unit.c(unit(1, "npc") - lwidth, lwidth)))
  grid.newpage()
  grid.draw(combined)
  
  # return gtable invisibly
  invisible(combined)
}

#Generate extract of freeform text answers
txtout <- function(data,colname)
{
  filename <- paste(toString(colname),toString(data[3,19]), ".txt", sep="")
  colNum <- match(toString(colname), names(data))
  txtResp <- subset(data, data[colNum] !="")
  txtResp <- txtResp[c(match("ResponseId", names(data)),match("Q2.1", names(data)),match("Q4.1", names(data)),match("Q4.2", names(data)),colNum)] 
  close(file(filename, open="w"))
  lapply(txtResp, write.table, filename, append=TRUE, sep="\n")
}
# Function to print comments as R-output string with line breaks
#printComment <- function(column)
#{
#comment <- column
#comment <- subset(comment, comment !="" & comment !="n/a" & comment !="N/A" & comment !="none")
#}

#some data cleaning
#Some hacks to adjust naming of categories in graphs and calculations
data$Q2.16 <- gsub("No - OPTOINAL: name the top reason:&nbsp;", "No", data$Q2.16)
data$Q2.16 <- gsub("Yes - OPTIONAL: name the top reason:&nbsp;", "Yes", data$Q2.16)
data$Q4.4 <- gsub("&lt; 25", "<25", data$Q4.4)
data$Q4.4 <- gsub("> 65", "65+", data$Q4.4)
data$Q2.2 <- gsub("less than 1 year", "1 year or less", data$Q2.2)
data$Q2.2 <- gsub("more than 3 years", "3+ years", data$Q2.2)
data$Q2.7_5 <- gsub("&quot;Enter once, use often&quot;: Automatically sharing information with institutions/ organisations/ funders.", "Enter once, use often", data$Q2.7_5)
data$Q2.12_1 <- gsub("[()]","" ,data$Q2.12_1)
data$Q2.12_1 <- gsub("Automatically updating research outputs/ publications listed in my ORCID record CrossRef, Scopus, Researcher ID, DataCite","Automatically updating research outputs/ publications listed in my ORCID record", data$Q2.12_1)
data$Q2.12_3 <- gsub("[()]","" ,data$Q2.12_3)
data$Q2.12_3 <- gsub("Submission of publications articles, books, posters", "Submission of publications", data$Q2.12_3)
data$Q4.1 <- gsub("Psychology & Neuroscience","Psychology and Neuroscience" ,data$Q4.1)
data$Q4.1 <- gsub("Physics & Astronomy","Physics and Astronomy" ,data$Q4.1)
data$Q4.1 <- gsub("Geography & Sustainable Development","Geography and Sustainable Development" ,data$Q4.1)
data$Q4.1 <- gsub("Philosophical, Anthropological & Film Studies","Philos., Anthr., Film Stud." ,data$Q4.1)
data$Q4.2 <- gsub("[()]","" ,data$Q4.2)
data$Q4.2 <- gsub("Academic Research and Teaching staff e.g. Professor, Reader, Lecturer","Academic Research and Teaching staff" ,data$Q4.2)
data$Q4.2 <- gsub("Research only staff e.g. Research Fellow, Postdoctoral Researcher","Research only staff" ,data$Q4.2)
data$Q4.2 <- gsub("Teaching only staff e.g. Teaching Fellow","Teaching only staff" ,data$Q4.2)
data$Q4.2 <- gsub("Teaching only staff e.g. Teaching Fellow","Teaching only staff" ,data$Q4.2)
#assigning employment role to participants who provided "other" as their job role but can be assigned to one of the groups
data$Q4.2<- (ifelse(data$Q4.3!="Now postdoc at different institution but was PhD at St Andrews", data$Q4.2,"PhD Student"))
#data$Q4.2<- (ifelse(data$Q4.3!="Senior Scientific Officer", data$Q4.2,"Research only staff"))

##----respRateDept
aggDept<- subset(data, Q4.1 !="")
aggDept$count <- 1
aggDept<- aggregate(aggDept$count, by=list(aggDept$Q4.1,aggDept$Q4.2), FUN=sum, na.rm=TRUE)
names(aggDept)[names(aggDept)=="Group.1"] <- "Unit"
names(aggDept)[names(aggDept)=="Group.2"] <- "Role"
names(aggDept)[names(aggDept)=="x"] <- "surveyResp"
aggStaff2 <- merge(aggDept, aggStaff, by="Unit")
percentage <- 100*(aggStaff2$surveyResp/(aggStaff2$Student.Total + aggStaff2$Staff_total))
aggStaff2$percentResp <- as.numeric(sprintf("%1.1f",percentage))
aggStaff2$Role <- gsub("Academic Research and Teaching staff|Research only staff|Teaching only staff|Other", "Staff", aggStaff2$Role)
aggStaff2$Role <- gsub("PhD Student|Masters Student", "Students", aggStaff2$Role)
aggStaff2_deptRoleSum <-aggregate(aggStaff2[,-c(1:2)], by=list(aggStaff2$Unit, aggStaff2$Role), FUN=sum, na.rm=TRUE)
aggStaff2_deptSum <-aggregate(aggStaff2[,-c(1:2)], by=list(aggStaff2$Unit), FUN=sum, na.rm=TRUE)

ggplot(aggStaff2_deptRoleSum, aes(x=reorder(label_wrap_mod(Group.1, width=30),surveyResp, sum), 
	y=surveyResp, fill=label_wrap_mod(Group.2, width=25)))+ coord_flip()+
  geom_bar(stat="Identity", width=0.8) +
  scale_fill_manual(values = c("gray65","gray30"))+
  theme(legend.position="bottom", axis.title.y = element_blank(),axis.title.x = element_blank(), 
	legend.title = element_blank(), text = element_text(size=14),panel.background=element_rect(fill="white")) +
  geom_text(aes(label= surveyResp),position=position_stack(vjust=0.5),size=3, color="white") +
  geom_text(data=aggStaff2_deptSum, aes(y=surveyResp,x=reorder(label_wrap_mod(Group.1, width=30),surveyResp, sum), 
	label=surveyResp, fill=NULL),size=4, color="gray50", hjust=-0.75)+
  geom_text(data=aggStaff2_deptSum, aes(y=33,x=reorder(label_wrap_mod(Group.1, width=30),surveyResp, sum), 
	label=paste(sprintf("(%0.1f",percentResp),"%)"), fill=NULL),size=4, color="gray50") +
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,35))+
  ylab("Count")

##----respRateRole
aggRole <- subset(data, Q4.2!="")
aggRole$count <- 1
aggRole <- aggregate(aggRole$count, by=list(aggRole$Q4.2), FUN=sum, na.rm=TRUE)

ggplot(aggRole, aes(y=aggRole$x, fill=reorder(label_wrap_mod(Group.1, width=35), x, sum),x=""))+
  geom_bar(stat="identity", width=0.5, color="white")+ coord_flip()+
 scale_fill_brewer(palette="Dark2")+ 
  theme(legend.position="bottom", axis.title.y = element_blank(),axis.text.y=element_blank(),axis.text.x=element_blank(),
   axis.title.x = element_blank(), legend.title = element_blank(), 
   text = element_text(size=14), panel.background=element_rect(fill="white"),legend.key.height=unit(2.25, "lines"), axis.ticks=element_blank()) + 
  geom_text(aes(label=x),position=position_stack(vjust=0.5), vjust=2, size=4)

##----respRateAge
aggAge <- subset(data, Q4.4 !="")
aggAge$count <- 1
aggAge <- aggregate(aggAge$count, by=list(aggAge$Q4.4, subset(data, Q4.4 !="")$Q2.1), FUN=sum, na.rm=TRUE)
ageTotal <- aggregate(aggAge$x, by=list(aggAge$Group.1), FUN=sum, na.rm=TRUE)

ggplot(data=aggAge, aes(label_wrap_mod(aggAge$Group.1, width=25), aggAge$x, fill=aggAge$Group.2))+
  geom_bar(stat="Identity", width=0.8) +
  theme(legend.position="right", legend.title = element_blank(), text = element_text(size=14),panel.background=element_rect(fill="white")) + 
  scale_y_continuous(breaks=pretty_breaks(n=10))+
  geom_text(data=subset(aggAge, x>2),aes(x=Group.1 ,y=x, label=x, fill=subset(aggAge, x>2)$Group.2),position=position_stack(vjust=0.5),size=4, color="white")+
  geom_text(data=ageTotal, aes(y=x, x=Group.1, label=paste("total: ", x), fill=NULL),vjust=-0.25,size=4, color="gray50")+
  ylab("count") + xlab("Age group")

##----IDcount
iDs <- subset(data, Q2.1!="")
ggplot(iDs, aes(iDs$Q2.1)) +
  geom_bar(stat="count", width=0.6) +
  theme(axis.title.x = element_blank(), text = element_text(size=12),panel.background=element_rect(fill="white")) + 
  geom_text(stat="count", aes(label=..count..),vjust=1.5, colour="white", size =4)

#----deptID
#plot with sorted bars
aggDept<- subset(data, Q4.1 !="")
aggDept$count <- 1
aggDept<- aggregate(aggDept$count, by=list(aggDept$Q4.1,aggDept$Q2.1), FUN=sum, na.rm=TRUE)
names(aggDept)[names(aggDept)=="Group.1"] <- "Unit"
names(aggDept)[names(aggDept)=="Group.2"] <- "ORCIDiD"
names(aggDept)[names(aggDept)=="x"] <- "surveyResp"
aggStaff2 <- merge(aggDept, staff, by="Unit")
percentage <- 100*(aggStaff2$surveyResp/(aggStaff2$Student.Total + aggStaff2$Staff_total))
aggStaff2$percentResp <- as.numeric(sprintf("%1.1f",percentage))
aggStaff2_deptSum <-aggregate(aggStaff2[,-c(1:2)], by=list(aggStaff2$Unit), FUN=sum, na.rm=TRUE)

ggplot(aggDept, aes(x=reorder(label_wrap_mod(Unit, width=30),surveyResp, sum), y=surveyResp, fill=label_wrap_mod(ORCIDiD, width=25)))+ 
  geom_bar(stat="Identity", width=0.8) + coord_flip()+
  theme(legend.position="bottom", axis.title.y = element_blank(),axis.title.x = element_blank(), legend.title = element_blank(), text = element_text(size=14),panel.background=element_rect(fill="white")) +
  geom_text(aes(label= surveyResp),position=position_stack(vjust=0.5),size=3, color="white") +
  geom_text(data=aggStaff2_deptSum, aes(y=26,x=reorder(label_wrap_mod(Group.1, width=30),surveyResp, sum), label=surveyResp, fill=NULL),size=4, color="gray50", hjust=-0.75)+
  geom_text(data=aggStaff2_deptSum, aes(y=33,x=reorder(label_wrap_mod(Group.1, width=30),surveyResp, sum), label=paste(sprintf("(%0.1f",percentResp),"%)"), fill=NULL),size=4, color="gray50") +
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,35))+
  ylab("Count")

#----roleID
roleOnly <- subset(data, Q4.2 !="")
roleOnly $count <- 1
roleOnly <- aggregate(roleOnly$count, by=list(roleOnly$Q4.2, roleOnly$Q2.1), FUN=sum, na.rm=TRUE)
ggplot(roleOnly , aes(x=reorder(label_wrap_mod(Group.1, width=35), x, sum), x, fill=Group.2))+ coord_flip()+
  geom_bar(stat="Identity", width=0.75) +
  theme(legend.position="right", axis.title.y = element_blank(), legend.title = element_blank(),text = element_text(size=12),panel.background=element_rect(fill="white")) +
  scale_y_continuous(breaks=pretty_breaks(n=10))+
  geom_text(aes(label= x),position=position_stack(vjust=0.5),size=4, color="white")+
  ylab("count")

##----ageCount
age <- subset(data, Q4.4 !="")$Q4.4
ggplot(subset(data, Q4.4 !=""), aes(label_wrap_mod(age, width=40), fill=subset(data, Q4.4 !="")$Q2.1)) +
  geom_bar(stat="count", width=0.6) +
  theme(axis.title.x = element_blank(), text = element_text(size=12), legend.title = element_blank(),panel.background=element_rect(fill="white")) + 
  scale_y_continuous(breaks=pretty_breaks(n=10)) + 
  geom_text(stat="count", aes(label=..count..),position=position_stack(vjust=0.5), size=4, colour="white")

##----ownID
#define ORCID iD and non-iD holders
iDHolder <- subset(data, Q2.1 == "Yes")
noID <- subset(data, Q2.1 == "No")
iDHolder_noFF <- iDHolder[, grep("_TEXT", colnames(iDHolder), value = TRUE, invert=TRUE)] # excluding the free-form answers
noID_noFF <-  noID[, grep("_TEXT", colnames(noID), value = TRUE, invert=TRUE)] # expluding the free-form answers

#reorder the data manually and plot the ownTime graph
ownTime <- factor(subset(iDHolder, Q2.2 != "")$Q2.2, levels=c("I'm not sure", "1 year or less", "1 -3 years", "3+ years"))
ggplot(subset(iDHolder, Q2.2 != ""), aes(ownTime)) +
  geom_bar(stat="count", width=0.6) +
  theme(axis.title.x = element_blank(), text = element_text(size=12),panel.background=element_rect(fill="white")) + 
  scale_y_continuous(breaks=pretty_breaks(n=10)) + 
  geom_text(stat="count", aes(label=..count..),vjust=1.5, colour="white")+
  geom_text(aes(label = scales::percent(..count../231), y= ..count.. ), stat= "count", vjust = -.5, color="gray30")

##----knowORCID
Q2.3_stack <- multiSelection(iDHolder_noFF, "Q2.3")
Q2.3_stack$count <- 1
Q2.3_stack<- aggregate(Q2.3_stack$count, by=list(Q2.3_stack$value), FUN=sum, na.rm=TRUE)
Q2.3_stack$percent <- 100*(Q2.3_stack$x/sum(Q2.3_stack$x))

ggplot(Q2.3_stack, aes(x=reorder(label_wrap_mod(Group.1, width=40), x, sum),x))+ coord_flip()+
  geom_bar(stat="Identity", position="dodge", width=0.8) +
  theme(legend.position="none", axis.title.y = element_blank(), legend.title = element_blank(), text = element_text(size=12),panel.background=element_rect(fill="white")) + 
  scale_y_continuous(breaks=pretty_breaks(n=10), limits = c(0,75))+
  geom_text(aes(label=x), hjust=1.5,size=3, position=position_dodge(1), color="white")+
  geom_text(aes(y=70,label=paste(sprintf("(%0.1f",percent),"%)"), fill=NULL),size=3, color="gray50") +
  ylab("count")

##----Motivation
#Motivation for sign-up with boxplot
Q2.4_stack <- multiSelection2(iDHolder_noFF, "Q2.4")
variable <- c("Q2.4_2","Q2.4_3","Q2.4_4", "Q2.4_8","Q2.4_5","Q2.4_6","Q2.4_9")
options <- c("Disambiguation of my name","Attaching my ORCID iD to my research output (attribution)", "Verification of affiliation by my institution", "Verification of affiliation by my funder", "Enter once, use often","Having a personal, permanent record of my academic identity", "Linking of my identifiers in one place")
Q2.4_options <- data.frame(variable, options)
Q2.4_stackOptions <- merge(Q2.4_stack, Q2.4_options, by="variable")
Q2.4_stackOptions$numValue <- as.numeric(as.character(Q2.4_stackOptions$value))

ggplot(Q2.4_stackOptions, aes(x=reorder(label_wrap_mod(options, width=25), numValue, mean), numValue))+ 
  geom_boxplot(color="gray50", width=0.5, fill="gray90") + coord_flip() +
  theme(axis.title.y = element_blank(), text = element_text(size=12), panel.background=element_rect(fill="white")) + 
  ylab("Mean rating") +
  stat_summary(fun.y=mean, colour="gray30", geom="text", show.legend = FALSE, vjust=-2.25, size = 3, aes(label=round(..y.., digits=2))) +
  stat_summary(fun.y=mean, geom="point", shape=19, size=4, color="gray30")

##----userFAQ
Q2.7_stack <- multiSelection(iDHolder_noFF, "Q2.7")
Q2.7_stack$count <- 1
Q2.7_stack<- aggregate(Q2.7_stack$count, by=list(Q2.7_stack$value), FUN=sum, na.rm=TRUE)
Q2.7_stack$percent <- 100*(Q2.7_stack$x/sum(Q2.7_stack$x))

ggplot(Q2.7_stack, aes(x=reorder(label_wrap_mod(Group.1, width=40), x, sum), x))+ coord_flip()+
  geom_bar(stat="Identity", position="dodge", width=0.8) +
  theme(legend.position="none", axis.title.y = element_blank(), legend.title = element_blank(), text = element_text(size=12),panel.background=element_rect(fill="white"))+
  scale_y_continuous(breaks=pretty_breaks(n=10),limits=c(0,40))+
  geom_text(aes(label=x), hjust=1.5,size=3, position=position_dodge(1), color="white")+
  geom_text(aes(y=35,label=paste(sprintf("(%0.1f",percent),"%)"), fill=NULL),size=3, color="gray50") +
  ylab("count")

##----ORCIDuse
#Using ORCID features
Q2.11 <- grep("Q2.11", names(data), value = TRUE)

Q2.11_stack <- multiSelection(data, "Q2.11")
variable <- c("Q2.11_20", "Q2.11_7", "Q2.11_1", "Q2.11_2", "Q2.11_3", "Q2.11_4","Q2.11_5","Q2.11_12","Q2.11_8","Q2.11_9", "Q2.11_10", "Q2.11_11")
options <- c("Associating my ORCID iD with publications", "Associating my ORCID iD with research data in contents of a digital repository", "Automatically updating research outputs listed in my ORCID record", "Letting PURE update my ORCID record", "Submission of publications", "Grant application process", "Connecting my ORCID iD to funding sources", "Letting a funder or Researchfish automatically update my ORCID record", "Creating a QR code for a poster", "Associating my ORCID iD with contents of an electronic lab notebook", "Authentication to ORCID using my University ID", "Registration at a professional association")
Q2.11_options <- data.frame(variable, options)
Q2.11_stackOptions <- merge(Q2.11_stack, Q2.11_options, by="variable")

used <- subset(Q2.11_stackOptions, value=="I have used it")
used$count <- 1
used <- aggregate(used$count, by=list(used$options),FUN=sum, na.rm=FALSE)
used <- rbind(used, c("Associating my ORCID iD with contents of an electronic lab notebook", 0))
used$x <- as.numeric(used$x)
used_plot<- ggplot(used, aes(Group.1,x,fill=label_wrap_mod(Group.1)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(),
	legend.title=element_blank(),panel.background=element_rect(fill="white"),text = element_text(size=12)) + 
  geom_text(aes(label=x),size=3, vjust=-0.5, color="gray40")+
  xlab("I have used it")+ylim(0,100)
 
not_used <- subset(Q2.11_stackOptions, value=="I  haven't used it")
not_used$count <- 1
not_used<- aggregate(not_used$count, by=list(not_used$options),FUN=sum, na.rm=FALSE)
not_used_plot<- ggplot(not_used, aes(Group.1,x,fill=label_wrap_mod(Group.1)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(),legend.title=element_blank(),panel.background=element_rect(fill="white"),text = element_text(size=12)) + 
  ylim(0,100)+
  geom_text(aes(label=x),size=3, vjust=-0.5, color="gray40")+
  xlab("I have not used it")

unknown <- subset(Q2.11_stackOptions, value=="I haven't heard about this")
unknown$count <- 1
unknown <- aggregate(unknown$count, by=list(unknown$options),FUN=sum, na.rm=FALSE)
unknown_plot<- ggplot(unknown, aes(Group.1,x,fill=label_wrap_mod(Group.1)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(), legend.title=element_blank(),panel.background=element_rect(fill="white"),text = element_text(size=12)) + 
  ylim(0,100)+
  geom_text(aes(label=x),size=3, vjust=-0.5, color="gray40")+
  xlab("I did not know of this")

grid_arrange_shared_legend(used_plot, not_used_plot, unknown_plot, ncol=1, nrow=3)

##----FeatureClarification
Q2.12_stack <- multiSelection(iDHolder_noFF, "Q2.12")
Q2.12_stack$count <- 1
Q2.12_stack <- aggregate(Q2.12_stack$count, by=list(Q2.12_stack$value), FUN=sum, na.rm=TRUE)
Q2.12_stack_t <- data.frame(t(Q2.12_stack), stringsAsFactors = FALSE)
repo1 <- Q2.12_stack_t[2,6]
repo2 <- Q2.12_stack_t[2,12]
repoMean <- (as.numeric(repo1) + as.numeric(repo2))/2
df <- data.frame("Attaching my ORCID iD to contents of a digital repository", repoMean)
names(df)[names(df)=="X.Attaching.my.ORCID.iD.to.contents.of.a.digital.repository."] <- "Group.1"
names(df)[names(df)=="repoMean"] <- "x"
Q2.12_stack<- rbind(Q2.12_stack, df)
Q2.12_stack <- Q2.12_stack[-c(6,12),]
Q2.12_stack$percent <-100*(Q2.12_stack$x/sum(Q2.12_stack$x))
ggplot(Q2.12_stack, aes(x=reorder(label_wrap_mod(Group.1, width=50), x, sum), x))+
  geom_bar(stat="Identity", position="dodge", width=0.8)+ coord_flip() +
  theme(legend.position="none", axis.title.y = element_blank(),legend.title = element_blank(), text = element_text(size=12),panel.background=element_rect(fill="white")) + 
  scale_y_continuous(breaks=pretty_breaks(n=10),limits=c(0,65))+
  geom_text(aes(label=x),hjust=1.5,size=3, position=position_dodge(1), color="white") + 
  geom_text(aes(y=55,label=paste(sprintf("(%0.1f",percent),"%)"), fill=NULL),size=3, color="gray50") +
   ylab("count")

##----PureConnected
#connecting to Pure
ORCIDinPure <- subset(iDHolder, Q2.8 !="")
ORCIDinPure_total <- nrow(ORCIDinPure)
ORCIDinPure_percent <- sprintf("%1.2f%%", 100*(ORCIDinPure_total)/iDHolder)

connected <- ggplot(ORCIDinPure , aes(ORCIDinPure$Q2.8)) +
  geom_bar(stat="count", width=0.8) +
  theme(axis.title.x = element_blank(), axis.line=element_line(color="gray90"), text = element_text(size=12), panel.background=element_rect(fill="white"),plot.title = element_text(hjust=0.5)) + 
  scale_y_continuous(breaks=pretty_breaks(n=10)) + 
  geom_text(stat="count", aes(label=..count..),vjust=1.5, colour="white")+
  geom_text(aes(label = scales::percent(..count../133), y= ..count.. ), stat= "count", vjust = -.5, color="gray30")+
  ggtitle("a)")

ORCIDconnection <- subset(iDHolder, Q2.9 !="")$Q2.9
connection <- ggplot(subset(iDHolder, Q2.9 !=""), aes(label_wrap_mod(ORCIDconnection, width=20)))+
  geom_bar(stat="count", width=0.8) +
  theme(axis.title.x = element_blank(),axis.line=element_line(color="gray90"), text = element_text(size=12), panel.background=element_rect(fill="white"),plot.title = element_text(hjust=0.5)) + 
  scale_y_continuous(breaks=pretty_breaks(n=10)) + 
  geom_text(stat="count", aes(label=..count..),vjust=1.5, colour="white") +
  geom_text(aes(label = scales::percent(..count../69), y= ..count.. ), stat= "count", vjust = -.5, color="gray30")+
  ggtitle("b)")

grid.arrange (connected, connection, ncol=2)

##----PureFail
Fail <- subset(iDHolder, Q2.10 !="")$Q2.10
ORCIDconnectionFail <- as.data.frame(Fail)
ORCIDconnectionFail$count <- 1
ORCIDconnectionFail <- aggregate(ORCIDconnectionFail$count, by=list(ORCIDconnectionFail$Fail), FUN=sum, na.rm=TRUE)
ORCIDconnectionFail$percent <- 100*(ORCIDconnectionFail$x/sum(ORCIDconnectionFail$x))
ggplot(ORCIDconnectionFail, aes(x=reorder(label_wrap_mod(Group.1, width=20),x,sum), x))+ coord_flip()+
  geom_bar(stat="Identity", position="dodge", width=0.8) +
  theme(legend.position="none",axis.title.y = element_blank(), legend.title = element_blank(), text = element_text(size=12),panel.background=element_rect(fill="white")) + 
  scale_y_continuous(breaks=pretty_breaks(n=10),limits=c(0,50))+
  geom_text(aes(label=x), hjust=1.5,size=4, position=position_dodge(1), color="white")+
  geom_text(aes(y=45,label=paste(sprintf("(%0.1f",percent),"%)"), fill=NULL),size=3, color="gray50") +
  ylab("count")

##----recommendation
recommend <- subset(iDHolder, Q2.16 !="")$Q2.16
ggplot(subset(iDHolder, Q2.16 !=""), aes(recommend)) +
  geom_bar(stat="count", width=0.75) +
  theme(axis.title.x = element_blank(), text = element_text(size=12), panel.background=element_rect(fill="white")) + 
  scale_y_continuous(breaks=pretty_breaks(n=10)) + 
  geom_text(stat="count", aes(label=..count..),vjust=1.5, colour="white")+
  geom_text(aes(label = scales::percent(..count../123), y= ..count.. ), stat= "count", vjust = -.5, color="gray30")
  

##----Benefit
##iD holders
Q2.15_stack <- multiSelection(iDHolder_noFF, "Q2.15")
variable <- c("Q2.15_1","Q2.15_2","Q2.15_3","Q2.15_4","Q2.15_5","Q2.15_6","Q2.15_7","Q2.15_8","Q2.15_9","Q2.15_10","Q2.15_11","Q2.15_12","Q2.15_13")
options <- c("Researchers","Early career researchers/ research students","Publishers","Funders","Research Managers","Librarians","Professional Associations","Research Councils","Research/ institutional repositories","Academic/ Research institutions","IT Services","Services creating research/ publication metrics","The research community as a whole")
Q2.15_options <- data.frame(variable, options)
Q2.15_stackOptions <- merge(Q2.15_stack, Q2.15_options, by="variable")

greatBenefit <- subset(Q2.15_stackOptions, value=="Benefits greatly")
greatBenefit$count <- 1
greatBenefit<- aggregate(greatBenefit$count, by=list(greatBenefit$options),FUN=sum, na.rm=TRUE)
greatBenefit_plot<- ggplot(greatBenefit, aes(Group.1,x,fill=label_wrap_mod(Group.1, width=25)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(), legend.title = element_blank(),panel.background=element_rect(fill="white"),text = element_text(size=12)) + 
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,70))+
  geom_text(aes(label=x),size=3, vjust=-0.5, color="gray40")+
  xlab("Beneftis greatly")

benefit <- subset(Q2.15_stackOptions, value=="Benefits somewhat")
benefit $count <- 1
benefit <- aggregate(benefit$count, by=list(benefit$options),FUN=sum, na.rm=TRUE)
benefit_plot<- ggplot(benefit, aes(Group.1,x,fill=label_wrap_mod(Group.1, width=25)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(), legend.title=element_blank(),panel.background=element_rect(fill="white"),text = element_text(size=12)) + 
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,70))+
  geom_text(aes(label=x),size=3, vjust=-0.5, color="gray40")+
  xlab("Beneftis somewhat")

noBenefit <- subset(Q2.15_stackOptions, value=="Does not benefit")
noBenefit$count <- 1
noBenefit <- aggregate(noBenefit$count, by=list(noBenefit$options),FUN=sum, na.rm=TRUE)
noBenefit_plot<- ggplot(noBenefit, aes(Group.1,x,fill=label_wrap_mod(Group.1, width=25)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(), legend.title=element_blank(),panel.background=element_rect(fill="white"),text = element_text(size=12)) + 
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,70))+
  geom_text(aes(label=x),size=3, vjust=-0.5, color="gray40")+
  xlab("Does not benefit")

noSure <- subset(Q2.15_stackOptions, value=="Not sure")
noSure$count <- 1
noSure <- aggregate(noSure$count, by=list(noSure$options),FUN=sum, na.rm=TRUE)
noSure_plot<- ggplot(noSure,aes(Group.1,x,fill=label_wrap_mod(Group.1, width=25)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(), legend.title=element_blank(),panel.background=element_rect(fill="white"), text = element_text(size=12)) + 
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,70))+
  geom_text(aes(label=x),size=3, vjust=-0.5,color="gray40")+
  xlab("Not sure")

grid_arrange_shared_legend(greatBenefit_plot,benefit_plot, noBenefit_plot, noSure_plot, ncol=1, nrow=4)

##generate an ordered list of the stakeholders thought to benefit
benefit_sum <- (benefit$x + greatBenefit$x)
Group <- benefit$Group.1
benefit_df <- data.frame(Group, benefit_sum)
benefit_df <- benefit_df[order(-benefit_sum),]
names(benefit_df)[names(benefit_df)=="Group"] <- "Benefits greatly/ somewhat"
names(benefit_df)[names(benefit_df)=="benefit_sum"] <- "Count"

##generate an ordered list of the stakeholders thought NOT to benefit
noBenefit_sum <- (noBenefit$x + noSure$x)
noBenefit_df <- data.frame(Group, noBenefit_sum)
noBenefit_df <- noBenefit_df[order(-noBenefit_sum),]
names(noBenefit_df)[names(noBenefit_df)=="Group"] <- "Does not benefit/ not sure"
names(noBenefit_df)[names(noBenefit_df)=="noBenefit_sum"] <- "Count"

##----BenefitnoID
Q3.4_stack <- multiSelection(noID_noFF, "Q3.4")
variable <- c("Q3.4_1","Q3.4_2","Q3.4_3","Q3.4_4","Q3.4_5","Q3.4_6","Q3.4_7","Q3.4_8","Q3.4_9","Q3.4_10","Q3.4_11","Q3.4_12","Q3.4_13")
options <- c("Researchers","Early career researchers/ research students","Publishers","Funders","Research Managers","Librarians","Professional Associations","Research Councils","Research/ institutional repositories","Academic/ Research institutions","IT Services","Services creating research/ publication metrics","The research community as a whole")
Q3.4_options <- data.frame(variable, options)
Q3.4_stackOptions <- merge(Q3.4_stack, Q3.4_options, by="variable")

greatBenefit2 <- subset(Q3.4_stackOptions, value=="Benefits greatly")
greatBenefit2$count <- 1
greatBenefit2<- aggregate(greatBenefit2$count, by=list(greatBenefit2$options),FUN=sum, na.rm=TRUE)
greatBenefit_plot2<- ggplot(greatBenefit2, aes(Group.1,x,fill=label_wrap_mod(Group.1, width=25)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(), legend.title=element_blank(),panel.background=element_rect(fill="white"), text = element_text(size=12)) + 
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,70))+
  geom_text(aes(label=x),size=3, vjust=-0.5, color="gray40")+
  xlab("Beneftis greatly")

benefit2 <- subset(Q3.4_stackOptions, value=="Benefits somewhat")
benefit2 $count <- 1
benefit2 <- aggregate(benefit2 $count, by=list(benefit2 $options),FUN=sum, na.rm=TRUE)
benefit_plot2<- ggplot(benefit2, aes(Group.1,x,fill=label_wrap_mod(Group.1, width=25)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(), legend.title=element_blank(),panel.background=element_rect(fill="white"), text = element_text(size=12)) + 
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,70))+
  geom_text(aes(label=x),size=3, vjust=-0.5, color="gray40")+
  xlab("Beneftis somewhat")

noBenefit2 <- subset(Q3.4_stackOptions, value=="Does not benefit")
noBenefit2 $count <- 1
noBenefit2 <- aggregate(noBenefit2 $count, by=list(noBenefit2 $options),FUN=sum, na.rm=TRUE)
noBenefit_plot2<- ggplot(noBenefit2, aes(Group.1,x,fill=label_wrap_mod(Group.1, width=25)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(), legend.title=element_blank(),panel.background=element_rect(fill="white"), text = element_text(size=12)) + 
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,70))+
  geom_text(aes(label=x),size=3, vjust=-0.5, color="gray40")+
  xlab("Does not benefit")

noSure2 <- subset(Q3.4_stackOptions, value=="Not sure")
noSure2$count <- 1
noSure2 <- aggregate(noSure2$count, by=list(noSure2$options),FUN=sum, na.rm=TRUE)
noSure_plot2<- ggplot(noSure2, aes(Group.1,x,fill=label_wrap_mod(Group.1, width=25)))+
  geom_bar(stat="Identity", position="dodge", width=0.9, color="white") +
  theme(axis.line=element_line(color="gray90"),axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.y = element_blank(), legend.title=element_blank(),panel.background=element_rect(fill="white"), text = element_text(size=12)) + 
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,70))+
  geom_text(aes(label=x),size=3, vjust=-0.5, color="gray40")+
  xlab("Not sure")

grid_arrange_shared_legend(greatBenefit_plot2,benefit_plot2, noBenefit_plot2, noSure_plot2, ncol=1, nrow=4)

benefit_sum2 <- (benefit2$x + greatBenefit2$x)
benefit_df2 <- data.frame(Group, benefit_sum2)
benefit_df2 <- benefit_df2[order(-benefit_sum2),]
names(benefit_df2)[names(benefit_df2)=="Group"] <- "Benefits greatly/ somewhat"
names(benefit_df2)[names(benefit_df2)=="benefit_sum2"] <- "Count"

noBenefit_sum2 <- (noBenefit2$x + noSure2$x)
noBenefit_df2 <- data.frame(Group, noBenefit_sum2)
noBenefit_df2 <- noBenefit_df2[order(-noBenefit_sum2),]
names(noBenefit_df2)[names(noBenefit_df2)=="Group"] <- "Does not benefit/ not sure"
names(noBenefit_df2)[names(noBenefit_df2)=="noBenefit_sum2"] <- "Count"

#----noIDreason
#no ORCID iD reason
reason <- subset(noID, Q3.1 !="")$Q3.1
noIDreason <- as.data.frame(reason)
noIDreason$count <- 1
noIDreason<- aggregate(noIDreason$count, by=list(noIDreason$reason), FUN=sum, na.rm=TRUE)
ggplot(noIDreason, aes(x=reorder(label_wrap_mod(Group.1, width=30), x, sum), x))+ coord_flip()+
  geom_bar(stat="Identity", position="dodge", width=0.5) +
  theme(legend.position="none", axis.title.y = element_blank(),legend.title = element_blank(), text = element_text(size=12),panel.background=element_rect(fill="white")) + 
  scale_y_continuous(breaks=pretty_breaks(n=10))+
  geom_text(aes(label=x),hjust=1.5,size=3, position=position_dodge(1), color="white")+
  ylab("count")

##----convincing
Q3.2_stack <- multiSelection2(noID_noFF, "Q3.2")
variable <- c("Q3.2_1","Q3.2_2","Q3.2_3,", "Q3.2_4","Q3.2_5","Q3.2_6","Q3.2_7","Q3.2_8","Q3.2_9")
options <- c("If it was used by publishers/ funders","If it was used for submission of work within the University","If it was used as identifier in REF2021", "If I knew more about who ORCID iDs are used by and what for", "If it was easier to sign up and maintain it","If it saves me time", "If I could use it on other online platforms", "If I could be reassured about privacy concerns","If they would feature more prominently in University systems/ web pages") 
Q3.2_options <- data.frame(variable, options)
Q3.2_stackOptions <- merge(Q3.2_stack, Q3.2_options, by="variable")

Q3.2_stackOptions$numValue <- as.numeric(as.character(Q3.2_stackOptions$value))
ggplot(Q3.2_stackOptions, aes(x=reorder(label_wrap_mod(options, width=30),numValue,mean), numValue))+ 
  geom_boxplot(color="gray50", fill="grey90", width=0.5) + coord_flip() +
  theme(axis.title.y = element_blank(), text = element_text(size=12), panel.background=element_rect(fill="white")) + 
  ylab("Mean rating by non-ORCID users") +
  stat_summary(fun.y=mean, colour="gray30", geom="text", show.legend = FALSE, vjust=-1.25, size = 3, aes(label=round(..y.., digits=1))) +
  stat_summary(fun.y=mean, geom="point", shape=19, size=4, color="gray30")

##----noID-FAQ
#noID holders FAQ
Q3.5_stack <- multiSelection(noID_noFF, "Q3.5")
Q3.5_stack$count <- 1
Q3.5_stack <- aggregate(Q3.5_stack$count, by=list(Q3.5_stack$value), FUN=sum, na.rm=TRUE)

#Hack to calculate the average of answers to questions which asked about the same thing
Q3.5_stack_t <- data.frame(t(Q3.5_stack), stringsAsFactors = FALSE)
repo1 <- Q3.5_stack_t[2,6]
repo2 <- Q3.5_stack_t[2,12]
repoMean <- (as.numeric(repo1) + as.numeric(repo2))/2
df <- data.frame("Attaching my ORCID iD to contents of a digital repository", repoMean)
names(df)[names(df)=="X.Attaching.my.ORCID.iD.to.contents.of.a.digital.repository."] <- "Group.1"
names(df)[names(df)=="repoMean"] <- "x"
Q3.5_stack<- rbind(Q3.5_stack, df)
Q3.5_stack<- Q3.5_stack[-c(6,12),]
Q3.5_stack$percent <- 100*(Q3.5_stack$x/sum(Q3.5_stack$x))
ggplot(Q3.5_stack, aes(x=reorder(label_wrap_mod(Group.1, width=50), x, sum), x))+
  geom_bar(stat="Identity", position="dodge", width=0.8) + coord_flip() +
  theme(legend.position="none", axis.title.y = element_blank(), legend.title = element_blank(), text = element_text(size=12),panel.background=element_rect(fill="white")) + 
  scale_y_continuous(breaks=pretty_breaks(n=10), limits=c(0,55))+
  geom_text(aes(label=x),hjust=1.5,size=3, position=position_dodge(1), color="white") + 
  geom_text(aes(y=48,label=paste(sprintf("(%0.1f",percent),"%)"), fill=NULL),size=3, color="gray50") +
  ylab("count")
